﻿using System.IO;
using System.IO.IsolatedStorage;
using System.Text;
using System.Windows;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.Docking;

namespace DockingSaveLoadLayout
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		private LayoutData data;

		public MainWindow()
		{
			InitializeComponent();
			this.XmlTextBox.DataContext = this.data = new LayoutData();
		}

		private string SaveLayoutAsString()
		{
			MemoryStream stream = new MemoryStream();
			this.Docking.SaveLayout(stream);
			stream.Seek(0, SeekOrigin.Begin);
			StreamReader reader = new StreamReader(stream);

			return reader.ReadToEnd();
		}

		private void SaveLayoutToFile()
		{
			using (IsolatedStorageFile storage = IsolatedStorageFile.GetUserStoreForAssembly())
			{
				using (var isoStream = storage.OpenFile("RadDocking_Layout.xml", FileMode.Create))
				{
					this.Docking.SaveLayout(isoStream);
					isoStream.Seek(0, SeekOrigin.Begin);
					StreamReader reader2 = new StreamReader(isoStream);
				}
			}
		}

		private void LoadLayoutFromString(string xml)
		{
			using (Stream stream = new MemoryStream(Encoding.UTF8.GetBytes(xml)))
			{
				stream.Seek(0, SeekOrigin.Begin);
				this.Docking.LoadLayout(stream);
			}
		}

		private void LoadLayoutFromFile()
		{
			using (IsolatedStorageFile storage = IsolatedStorageFile.GetUserStoreForAssembly())
			{
				var isoStream = storage.OpenFile("RadDocking_Layout.xml", FileMode.Open);
				using (isoStream)
				{
					this.Docking.LoadLayout(isoStream);
				}
			}
		}

		private void ButtonSaveLayoutToFileClick(object sender, RoutedEventArgs e)
		{
			this.SaveLayoutToFile();
			this.LoadLayoutFromFileButton.IsEnabled = true;
		}

		private void ButtonLoadLayoutFromFileClick(object sender, RoutedEventArgs e)
		{
			this.LoadLayoutFromFile();
		}

		private void CopyTextFromDocumentPane_Click(object sender, System.Windows.RoutedEventArgs e)
		{
			this.TextBox.Text = this.XmlTextBox.Text;
		}

		private void CopyTextToDocumentPane_Click(object sender, System.Windows.RoutedEventArgs e)
		{
			this.DocumentTextBox.Text = this.TextBox.Text;
		}

		private void LoadLayoutFromStrButtonClick_1(object sender, RoutedEventArgs e)
		{
			this.LoadLayoutFromString(this.data.Xml);
		}

		private void ButtonSaveLayoutToStrClick(object sender, RoutedEventArgs e)
		{
			this.data.Xml = this.SaveLayoutAsString();
			this.LoadLayoutFromStrButton.IsEnabled = true;
		}

		private void ButtonAddPaneClick(object sender, RoutedEventArgs e)
		{
			RadPane radPane = new RadPane() { Title = "New RadPane", Name = "NewRadPane" };
			RadDocking.SetSerializationTag(radPane, "NewRadPane");
			RadPaneGroup radPaneGroup = new RadPaneGroup();
			RadSplitContainer radSplitContainer = new RadSplitContainer() { InitialPosition = DockState.FloatingDockable };
			radPaneGroup.Items.Add(radPane);
			radSplitContainer.Items.Add(radPaneGroup);
			this.Docking.Items.Add(radSplitContainer);
		}

		private void RadButtonRemovePaneClick(object sender, RoutedEventArgs e)
		{
			this.Pane1.RemoveFromParent();
		}
	}
}
